@@ -21,9 +21,10 @@
 ##'
 ##' @examples
 ##' require(MuChPoint)
+##' require(Matrix)
 ##' mu=c(rep(c(rep(1,25),rep(0,25)),3))%*%t(rep(c(rep(0,25),rep(1,25)),3))
-##' Y=matrix(rnorm(150^2,0,5),150)+mu+t(mu)
-##' Y=as.matrix(Matrix::forceSymmetric(Y))
+##' Y=matrix(rnorm(150^2,0,2),150)+mu+t(mu)
+##' Y=as.matrix(forceSymmetric(Y))
 ##' res=MuChPoint(Y)
 ##' plot(res,Y,L=5,shiny=FALSE)
 ##' plot(res,Y,L=1:10,shiny=FALSE,ask=FALSE)
@@ -93,7 +94,7 @@ MuChPoint=function(Y,Lmax=nrow(Y)/2,N=NULL,cores=1,verbose=TRUE){
         Lmax=NULL
       }
     }else{
-      if ((floor(Lmax)!=Lmax)|(Lmax<1)|(Lmax>=n)){
+      if ((floor(Lmax)!=Lmax)||(Lmax<1)||(Lmax>=n)){
         if(is.null(N)){
           stop("\n Lmax must be an integer between 1 and n")
         }else{
@@ -148,7 +149,7 @@ MuChPoint=function(Y,Lmax=nrow(Y)/2,N=NULL,cores=1,verbose=TRUE){
         warning("\n N has been sorted by increasing order")
       }
     }
-    if ((N[1]<1)|(N[L]>=n)){
+    if ((N[1]<1)||(N[L]>=n)){
       stop("N must be an increasing positive integer vector between 1 and n-1")
     }
 
@@ -199,40 +200,6 @@ MuChPoint=function(Y,Lmax=nrow(Y)/2,N=NULL,cores=1,verbose=TRUE){
     S=S*4/n^2
     bt=matrix(0,0,0)
   }else{
-    ## Recherche des ruptures si N non donne
-    ### Calcul de C
-    # Cn1n2=matrix(0,n,n)
-    # if (verbose){
-    #   cat("\nComputation of Cn[n1,n2]\n")
-    #   pbbis=utils::txtProgressBar(min=0,max=n*(n+1)/2,style=3) ### Decalage pour n1
-    #   C=function(n1,n2){
-    #     if (n2>(n1+1)){
-    #       utils::setTxtProgressBar(pbbis,n1*(2*n-n1+1)/2+n2)
-    #       (n2-n1)*sum(((apply(Rij[,(n1+1):n2],1,sum))/(n2-n1) ##Rbar
-    #                    -(n+1)/2)^2)
-    #     }else{
-    #       0
-    #     }
-    #   }
-    # }else{
-    #   C=function(n1,n2){
-    #     if (n2>(n1+1)){
-    #       (n2-n1)*sum(((apply(Rij[,(n1+1):n2],1,sum))/(n2-n1) ##Rbar
-    #                    -(n+1)/2)^2)
-    #     }else{
-    #       0
-    #     }
-    #   }
-    # }
-    # if (cores==1){
-    #   Cn1n2[1:(n-1),2:n]=matrix(unlist(lapply(0:(n-2),function(n1){
-    #     unlist(lapply(2:n,function(n2){C(n1,n2)}))})),nrow=n-1,byrow=TRUE)
-    # }else{
-    #   Cn1n2[1:(n-1),2:n]=matrix(unlist(parallel::mclapply(0:(n-2),function(n1){
-    #     unlist(lapply(2:n,function(n2){C(n1,n2)}))},mc.cores=cores)),
-    #     nrow=n-1,byrow=TRUE)
-    # }
-    # diag(Cn1n2)=colSums(((Rij[,1:n])/-(n+1)/2)^2) ## Cas ou n1+1=n2
     ### Version Cpp
     if (verbose){
       cat("\nComputation of Cn[n1,n2]\n")
@@ -270,11 +237,10 @@ MuChPoint=function(Y,Lmax=nrow(Y)/2,N=NULL,cores=1,verbose=TRUE){
           IL[L,L:n]=sapply(L:n,function(n0){IL[L-1,ind[L,n0]]+Cn1n2[ind[L,n0]+1,n0]})
         }
       }
-      bt=matrix(0,Lmax,Lmax)
-      bt[1,1]=ind[1,n]
-      if (Lmax>1){
-        for (L in 2:Lmax){
-          bt[L,L]=ind[L,n]
+      bt=matrix(0,Lmax+1,Lmax+1)
+      for (L in 1:(Lmax+1)){
+        bt[L,L]=ind[L,n]
+        if (L>1){
           for (k in (L-1):1){
             bt[L,k]=ind[k,bt[L,k+1]]
           }
