@@ -40,16 +40,16 @@ setClass(
 setMethod("print", "MuChPoint", definition =
             function(x, N=NULL) {
               cat("Multiple Change-Point (MuChPoint)\n")
-              cat("- max number of change-points :", length(methods::slot(x,"N")),"\n")
+              cat("- max number of change-points :", length(slot(x,"N")),"\n")
               if (!is.null(N)){
                 if (is.numeric(N)){
-                  if ((N<1)|(N>nrow(methods::slot(x,"bt")))){
-                    warning("N must be a positive integer less than ",nrow(methods::slot(x,"bt")))
+                  if ((N<1)|(N>nrow(slot(x,"bt")))){
+                    warning("N must be a positive integer less than ",nrow(slot(x,"bt")))
                   }else{
-                    cat("- position of change-points for N equal to",as.character(N),":", methods::slot(x,"bt")[N,1:N], "\n")
+                    cat("- position of change-points for N equal to",as.character(N),":", slot(x,"bt")[N,1:N], "\n")
                   }
                 }else{
-                  warning("N must be a positive integer less than ",nrow(methods::slot(x,"bt")))
+                  warning("N must be a positive integer less than ",nrow(slot(x,"bt")))
                 }
               }
               cat("Use 'plot' to represent the results with 'shiny=TRUE' to select the number of break points \n")
@@ -66,9 +66,10 @@ setMethod("print", "MuChPoint", definition =
 ##'
 ##' @examples
 ##' require(MuChPoint)
+##' require(Matrix)
 ##' mu=c(rep(c(rep(1,25),rep(0,25)),3))%*%t(rep(c(rep(0,25),rep(1,25)),3))
 ##' Y=matrix(rnorm(150^2,0,2),150)+mu+t(mu)
-##' Y=as.matrix(Matrix::forceSymmetric(Y))
+##' Y=as.matrix(forceSymmetric(Y))
 ##' res=MuChPoint(Y)
 ##' summary(res)
 ##'
@@ -76,7 +77,7 @@ setMethod("print", "MuChPoint", definition =
 setMethod("summary", "MuChPoint", definition =
             function(object) {
               cat("Multiple Change-Point (MuChPoint)\n")
-              cat("- max number of change-points :", length(methods::slot(object,"N")),"\n")
+              cat("- max number of change-points :", length(slot(object,"N")),"\n")
               cat("- slot '@bt' contains the break-points for each L (use 'print' with 'L=...' to display the positions)\n")
               cat("Use 'plot' to represent the results with 'shiny=TRUE' to select the number of break points \n")
               invisible(object)
@@ -98,7 +99,7 @@ setMethod("show", "MuChPoint", definition =
 ##' @param L the summarized matrix with L break-points (L can be a vector).
 ##' @param ask If \code{TRUE}, to hit will be necessary to see next plot.
 ##'
-##' @seealso \code{\linkS4class{MuChPoint}}, \code{\link{capushe}}.
+##' @seealso \code{\linkS4class{MuChPoint}}, \code{\link[capushe]{capushe}}.
 ##' @rdname plot-MuChPoint
 ##'
 ##' @references Article: BRAULT V., OUADAH S., SANSONNET L. and LEVY-LEDUC C. Nonparametric
@@ -107,14 +108,39 @@ setMethod("show", "MuChPoint", definition =
 ##'
 ##' @examples
 ##' require(MuChPoint)
+##' require(Matrix)
 ##' mu=c(rep(c(rep(1,25),rep(0,25)),3))%*%t(rep(c(rep(0,25),rep(1,25)),3))
 ##' Y=matrix(rnorm(150^2,0,2),150)+mu+t(mu)
-##' Y=as.matrix(Matrix::forceSymmetric(Y))
+##' Y=as.matrix(forceSymmetric(Y))
 ##' res=MuChPoint(Y)
 ##' plot(res,Y,L=5,shiny=FALSE)
 ##' plot(res,Y,L=1:10,shiny=FALSE,ask=FALSE)
 ##'
 ##' @exportMethod plot
+##' @importFrom grDevices gray
+##' @importFrom grDevices rgb
+##' @importFrom methods slot
+##' @importFrom shiny fluidPage
+##' @importFrom shiny fluidRow
+##' @importFrom shiny column
+##' @importFrom shiny plotOutput
+##' @importFrom shiny mainPanel
+##' @importFrom shiny sidebarPanel
+##' @importFrom shiny tabPanel
+##' @importFrom shiny textOutput
+##' @importFrom shiny tabsetPanel
+##' @importFrom shiny sliderInput
+##' @importFrom shiny renderText
+##' @importFrom shiny renderPlot
+##' @importFrom shiny checkboxInput
+##' @importFrom shiny shinyApp
+##' @importFrom capushe DDSE
+##' @importFrom capushe Djump
+##' @importFrom graphics par
+##' @importFrom graphics image
+##' @importFrom graphics abline
+##' @importFrom graphics title
+##' @importFrom Matrix bdiag
 
 setMethod(
   f="plot",
@@ -134,10 +160,10 @@ setMethod(
     }else{
       if (length(col)==1){
         if (col=="GrayLevel"){
-          mypalette=grDevices::gray(seq(0,1, length=256))
+          mypalette=gray(seq(0,1, length=256))
         }else{
-          mypalette=c(grDevices::rgb((0:201)/201*200,(0:201)/201*200,255,maxColorValue = 255),"white",
-                      grDevices::rgb(255,(0:201)/201*200,(0:201)/201*200,maxColorValue = 255)[201:0])
+          mypalette=c(rgb((0:201)/201*200,(0:201)/201*200,255,maxColorValue = 255),"white",
+                      rgb(255,(0:201)/201*200,(0:201)/201*200,maxColorValue = 255)[201:0])
         }
       }else{
         mypalette=col
@@ -148,7 +174,7 @@ setMethod(
       if (!is.numeric(L)){
         stop("L must be a positive ingeter vector between 1 and Lmax")
       }
-      if ((length(methods::slot(x,"bt"))==0)&&(any(L!=length(x@N)))){
+      if ((length(slot(x,"bt"))==0)&&(any(L!=length(x@N)))){
         stop("bt is required for the evolution. In the function MuChPoint, use
              the option Lmax instead of the option N")
       }
@@ -170,36 +196,36 @@ setMethod(
     }
     if (shiny){
       ############### Version Shiny
-      ui_MuChPoint = shiny::fluidPage(
-        shiny::fluidRow(
-          shiny::column(12,shiny::sliderInput("L","Number of breaks",min=1,max=length(x@S),step=1,value=L))),
-        shiny::textOutput("result2"),
-        shiny::tabsetPanel(type = "tabs",
-                           shiny::tabPanel('Out of MuChPoint',
-                                           shiny::checkboxInput("Gray", "Gray version", col=="GrayLevel"),
-                                           shiny::plotOutput(outputId="MuChPoint", height="1000px")),
-                           shiny::tabPanel('Capushe',shiny::fluidRow(
+      ui_MuChPoint = fluidPage(
+        fluidRow(
+          column(12,sliderInput("L","Number of breaks",min=1,max=length(x@S),step=1,value=L[1]))),
+        textOutput("result2"),
+        tabsetPanel(type = "tabs",
+                           tabPanel('Out of MuChPoint',
+                                           checkboxInput("Gray", "Gray version", col=="GrayLevel"),
+                                           plotOutput(outputId="MuChPoint", height="1000px")),
+                           tabPanel('Capushe',fluidRow(
 
-                             shiny::sidebarPanel("For DDSE and Djump",
-                                                 shiny::sliderInput("L2","Number of penalties",min=1,
+                             sidebarPanel("For DDSE and Djump",
+                                                 sliderInput("L2","Number of penalties",min=1,
                                                                     max=length(x@S),
                                                                     value=c(1,min(length(x@S),
                                                                                   max(1,floor(nrow(y)*0.45)))),
                                                                     step=1)
                              ),
-                             shiny::sidebarPanel("For DDSE",
-                                                 shiny::sliderInput("pct","pct",min=0,max=1,value=0.1,
+                             sidebarPanel("For DDSE",
+                                                 sliderInput("pct","pct",min=0,max=1,value=0.1,
                                                                     step=0.01)
                              )),
 
-                             shiny::mainPanel("Out of Capushe",
-                                              shiny::column(12,shiny::plotOutput(outputId="Capushe")),
-                                              shiny::column(12,shiny::plotOutput(outputId="Capushe2")))))
+                             mainPanel("Out of Capushe",
+                                              column(12,plotOutput(outputId="Capushe")),
+                                              column(12,plotOutput(outputId="Capushe2")))))
 
       )
       ########### Partie Server
       server_MuChPoint = function(input, output) {
-        output$result2 <- shiny::renderText({
+        output$result2 <- renderText({
           n=nrow(y)*(nrow(y)+1)
           K=(2:(length(x@S)+1))*(3:(length(x@S)+2))
           AIC=which.max(x@S[1:length(x@S)]-K)
@@ -207,61 +233,61 @@ setMethod(
           paste0(AIC," break-points chosen by AIC and ",BIC," break-points chosen by BIC")
 
         })
-        output$MuChPoint<- shiny::renderPlot({
+        output$MuChPoint<- renderPlot({
           if (input$Gray){
             plot(x,y,shiny=FALSE,L=input$L,col="GrayLevel",ask=FALSE)
           }else{
             plot(x,y,shiny=FALSE,L=input$L,col=col,ask=FALSE)
           }
         })
-        output$Capushe<- shiny::renderPlot({
+        output$Capushe<- renderPlot({
           data=data.frame(matrix(c(input$L2[1]:input$L2[2],input$L2[1]:input$L2[2],
                                    input$L2[1]:input$L2[2],-x@S[input$L2[1]:input$L2[2]]),
                                  ncol=4))
-          cap=capushe::DDSE(data,pct =input$pct)
+          cap=DDSE(data,pct =input$pct)
           plot(cap,newwindow=FALSE)
         })
-        output$Capushe2<- shiny::renderPlot({
+        output$Capushe2<- renderPlot({
           data=data.frame(matrix(c(input$L2[1]:input$L2[2],input$L2[1]:input$L2[2],
                                    input$L2[1]:input$L2[2],-x@S[input$L2[1]:input$L2[2]]),
                                  ncol=4))
           n=nrow(y)*(nrow(y)+1)
-          cap=capushe::Djump(data,Careajump=sqrt(log(n)/n))
+          cap=Djump(data,Careajump=sqrt(log(n)/n))
           plot(cap,newwindow=FALSE)
         })
       }
       ########### Affichage
-      shiny::shinyApp(ui = ui_MuChPoint,server=server_MuChPoint)
+      shinyApp(ui = ui_MuChPoint,server=server_MuChPoint)
 
     }else{
-      par_temp=graphics::par()
+      par_temp=par()
       par_old=list(mfrow=par_temp$mfrow,oma=par_temp$oma)
-      graphics::par(mfrow=c(1,2),oma=c(0,0,3,0))
+      par(mfrow=c(1,2),oma=c(0,0,3,0))
       for (liter in L){
         N=bt[liter,1:liter]
         ty=sort(nrow(y)+1-N)
         tx=N
         ## Diplay of the original matrix
-        graphics::image(1:nrow(y),1:nrow(y),t(y)[,nrow(y):1],xlab="",ylab="",xaxt="n",
+        image(1:nrow(y),1:nrow(y),t(y)[,nrow(y):1],xlab="",ylab="",xaxt="n",
                         yaxt="n",main="Original data",col=mypalette,breaks=brek)
 
-        graphics::abline(v=tx+0.5,col="purple")
-        graphics::abline(h=ty-0.5,col="purple")
+        abline(v=tx+0.5,col="purple")
+        abline(h=ty-0.5,col="purple")
         # Diplay of the estimated matrix
         emplz=diff(unique(c(0,N,nrow(y))))
-        z=as.matrix(Matrix::bdiag(lapply(emplz,function(i){rep(1,i)})))
+        z=as.matrix(bdiag(lapply(emplz,function(i){rep(1,i)})))
         nz=length(emplz)
         resum=as.matrix(t(z)%*%y%*%z/(emplz%*%t(emplz)))
-        graphics::image(y = unique(c(1,ty,nrow(y)+1)),
+        image(y = unique(c(1,ty,nrow(y)+1)),
                         x = unique(c(1,tx,nrow(y)+1)),
                         z = as.matrix(resum[,nz:1]),xlab="",ylab="",xaxt="n",yaxt="n",
                         main="Estimated matrix",col=mypalette)
-        graphics::abline(v=tx,col="purple")
-        graphics::abline(h=ty,col="purple")
-        graphics::title(main=paste(as.character(length(N))," break-points", sep=""),outer=TRUE)
-        graphics::par(ask=ask)
+        abline(v=tx,col="purple")
+        abline(h=ty,col="purple")
+        title(main=paste(as.character(length(N))," break-points", sep=""),outer=TRUE)
+        par(ask=ask)
       }
-      graphics::par(par_old)
+      par(par_old)
     }
   })
 
